'use strict';

var _ = require('..');

var _2 = _interopRequireDefault(_);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _acorn = require('acorn');

var _escodegen = require('escodegen');

var _escodegen2 = _interopRequireDefault(_escodegen);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const parseCode = input => (0, _acorn.parse)(input, {
  ecmaVersion: 6,
  sourceType: 'module'
});


function readFile(filePath) {
  return _fs2.default.readFileSync(_path2.default.resolve(__dirname, `${ filePath }.txt`), { encoding: 'utf8' });
}

describe('inline CSS Loader', () => {
  const exportNodes = [];
  exportNodes.push(readFile('exportNode/es5'));
  exportNodes.push(readFile('exportNode/es6'));
  exportNodes.push(readFile('exportNode/babel'));
  exportNodes.push(readFile('exportNode/babelLoose'));
  exportNodes.push(readFile('exportNode/babelSpread'));
  exportNodes.push(readFile('exportNode/babelRuntimeSpread'));
  exportNodes.push(readFile('exportNode/webpack'));
  exportNodes.push(readFile('exportNode/webpack2'));
  exportNodes.push(readFile('exportNode/webpack3'));
  exportNodes.push(readFile('exportNode/webpack4'));
  exportNodes.push(readFile('exportNode/webpack5'));
  it('should find nodes', () => {
    exportNodes.forEach(n => {
      const tree = parseCode(n);
      expect(tree).toBeDefined();
      const root = _2.default.getExportsNode(tree.body);
      expect(root).toBeDefined();
      expect(root.type).toBe('ObjectExpression');
    });
  });

  const fullparseCode = [];
  fullparseCode.push(readFile('fullObjects/simple'));
  fullparseCode.push(readFile('fullObjects/spread'));
  fullparseCode.push(readFile('fullObjects/media'));
  it('parseCode, doNothing', () => {
    fullparseCode.forEach(obj => {
      const generatedFromTree = _escodegen2.default.generate(parseCode(obj));
      expect(generatedFromTree).toBe(_2.default.call({}, obj));
    });
  });
  //
  it('temp', () => {
    const temp = {
      input: readFile('transforms/complexIn'),
      output: readFile('transforms/complexOut')
    };
    const generatedFromTree = _escodegen2.default.generate(parseCode(temp.output));
    expect(generatedFromTree).toBe(_2.default.call({}, temp.input));
  });
  //
  const transforms = [];
  transforms.push({
    input: readFile('transforms/simpleIn'),
    output: readFile('transforms/simpleOut')
  });
  transforms.push({
    input: readFile('transforms/spreadIn'),
    output: readFile('transforms/spreadOut')
  });
  transforms.push({
    input: readFile('transforms/complexIn'),
    output: readFile('transforms/complexOut')
  });

  it('transforms', () => {
    transforms.forEach(t => {
      const generatedFromTree = _escodegen2.default.generate(parseCode(t.output));
      expect(generatedFromTree).toBe(_2.default.call({}, t.input));
    });
  });

  it('complexRealTransform', () => {
    const inp = readFile('transforms/complexRealIn');
    const out = readFile('transforms/complexRealOut');
    const generatedFromTree = _escodegen2.default.generate(parseCode(out));
    expect(generatedFromTree).toBe(_2.default.call({}, inp));
    let inpES6 = readFile('transforms/complexRealInES6');
    let outES6 = readFile('transforms/complexRealOutES6');
    let generatedFromTreeES6 = _escodegen2.default.generate(parseCode(outES6));
    expect(generatedFromTreeES6).toBe(_2.default.call({}, inpES6));

    inpES6 = readFile('transforms/complexFlowRealInES6');
    outES6 = readFile('transforms/complexFlowRealOutES6');
    generatedFromTreeES6 = _escodegen2.default.generate(parseCode(outES6));
    expect(generatedFromTreeES6).toBe(_2.default.call({}, inpES6));
  });

  it('mediaQuery', () => {
    const inp = readFile('transforms/mediaQueryIn');
    const out = readFile('transforms/mediaQueryOut');
    const generatedFromTree = _escodegen2.default.generate(parseCode(out));
    expect(generatedFromTree).toBe(_2.default.call({}, inp));
  });

  const simple = [];
  simple.push({
    input: readFile('simple/simpleIn'),
    output: readFile('simple/simpleOut')
  });
  simple.push({
    input: readFile('simple/simpleES6In'),
    output: readFile('simple/simpleES6Out')
  });
  simple.push({
    input: readFile('simple/simpleOverrideIn'),
    output: readFile('simple/simpleOverrideOut')
  });

  it('simple', () => {
    simple.forEach(t => {
      const generatedFromTree = _escodegen2.default.generate(parseCode(t.output));
      expect(generatedFromTree).toBe(_2.default.call({}, t.input));
    });
  });

  it('webpack', () => {
    const inp = readFile('webpackIn');
    const out = readFile('webpackOut');
    const generatedFromTree = _escodegen2.default.generate(parseCode(out));
    expect(generatedFromTree).toBe(_2.default.call({}, inp));
  });
});